Struct rkyv::net::ArchivedIpv4Addr [−][src]
#[repr(transparent)]pub struct ArchivedIpv4Addr { /* fields omitted */ }Expand description
An archived Ipv4Addr.
Implementations
Returns true if this is a broadcast address (255.255.255.255).
See Ipv4Addr::is_broadcast() for more details.
Returns true if this address is in a range designated for documentation.
See Ipv4Addr::is_documentation() for more details.
Returns true if the address is link-local (169.254.0.0/16).
See Ipv4Addr::is_link_local() for more details.
Returns true if this is a loopback address (127.0.0.0/8).
See Ipv4Addr::is_loopback() for more details.
Returns true if this is a multicast address (224.0.0.0/4).
See Ipv4Addr::is_multicast() for more details.
Returns true if this is a private address.
See Ipv4Addr::is_private() for more details.
Returns true for the special ‘unspecified’ address (0.0.0.0).
See Ipv4Addr::is_unspecified() for more details.
Converts this address to an IPv4-compatible IPv6 address.
See Ipv4Addr::to_ipv6_compatible() for more
details.
Converts this address to an IPv4-mapped IPv6 address.
See Ipv4Addr::to_ipv6_mapped() for more details.