Struct rkyv::net::ArchivedIpv6Addr [−][src]
#[repr(transparent)]pub struct ArchivedIpv6Addr { /* fields omitted */ }Expand description
An archived Ipv6Addr.
Implementations
Returns true if this is a loopback address (::1).
See Ipv6Addr::is_loopback() for more details.
Returns true if this is a multicast address (ff00::/8).
See Ipv6Addr::is_multicast() for more details.
Returns true for the special ‘unspecified’ address (::).
See Ipv6Addr::is_unspecified() for more details.
Returns the sixteen eight-bit integers the IPv6 address consists of.